@@ -561,7 +561,7 @@ eel_show_yes_no_dialog (const char *primary_text,
 			const char *no_label,
 			GtkWindow *parent)
 {
-	GtkDialog *dialog = 0;
+	GtkDialog *dialog = NULL;
 	dialog = eel_create_question_dialog (primary_text,
 					     secondary_text,
 					     dialog_title == NULL ? _("Question") : dialog_title,
